---8<--- "README.md:description"

## Where to next?

If you want to use the tool to create input4MIPs files,
we recommend going to our [how-to guides][how-to-guides].
Some other potential points of interest:

- Getting Started instructions: [Getting Started][getting-started]
- (How-to guides, just in case you missed it the first time: [How-to...][how-to-guides])
- The command-line interface's documentation: [CLI](cli)
- The full API docs: [API reference](api/bookshelf/#bookshelf_1)
